cloogle.py
====================

Basic interfacing with the `Cloogle <https://cloogle.org>`_ API.

Links
-----
| PyPi: https://pypi.python.org/pypi/cloogle
| Source code: https://gitlab.science.ru.nl/cloogle/cloogle-py

Author & License
----------------

Cloogle.py is written and maintained by `Camil Staps <https://camilstaps.nl>`_.
It is licensed under MIT, see the LICENSE file for more details.
